@@ -22,7 +22,7 @@ urllib3.disable_warnings(InsecureRequestWarning)
 # 需要 pickle 的属性
 pickle_attr = [
     'meta', 'downloader', 'downloader_parser', 'cookie_jar', 'command', 'jump_spider',
-    'jump_spider_kwargs', 'jump_spider_middleware'
+    'jump_spider_kwargs', 'jump_request_middleware'
 ]
 
 
@@ -61,7 +61,7 @@ class Request:
         'meta',
         'jump_spider',
         'jump_spider_kwargs',
-        'jump_spider_middleware',
+        'jump_request_middleware',
     ]
 
     # 下载器
@@ -115,7 +115,7 @@ class Request:
             command: dict = None,
             jump_spider=None,
             jump_spider_kwargs: dict = None,
-            jump_spider_middleware=None,
+            jump_request_middleware=None,
             **kwargs
     ):
         """
@@ -133,7 +133,7 @@ class Request:
         :param filter_repeat: 是否过滤请求，settings.FILTER_REQUEST 启用生效，默认 False
         :param keep_session: 是否保持 session，默认 False
         :param keep_cookie: 不使用 session 时保持 cookie，默认 False
-        :param callback: 回调函数
+        :param callback: 回调函数，设置的时候会被转为字符串，只有使用时手动从 spider 提取
         :param priority: 启用优先级队列时的优先级，分数越大，优先级约低，默认 settings.DEFAULT_QUEUE_PRIORITY
         :param command: 自定义操作命令，用于自定义 downloader 时使用
         :param downloader: 自定义的下载器（局部）
@@ -141,7 +141,7 @@ class Request:
         :param meta: 自动向下传递参数，临时的直接 xxx=yyy，自动的 meta={'xxx':'yyy'}
         :param jump_spider: 跳转的 spider
         :param jump_spider_kwargs: 跳转的 spider 需要 self.xxx 的参数
-        :param jump_spider_middleware: 跳转的 spider 需要的请求中间件
+        :param jump_request_middleware: 跳转的 spider 需要的请求中间件
 
         Palp 参数（非用户设置）
         :param cookie_jar: cookie_jar，存储 cookie，这里使用的是 requests 模块的，其它请求的话可以自己提取
@@ -164,7 +164,7 @@ class Request:
         self.filter_repeat = filter_repeat
         self.downloader_parser = downloader_parser
         self.jump_spider_kwargs = jump_spider_kwargs
-        self.jump_spider_middleware = jump_spider_middleware
+        self.jump_request_middleware = jump_request_middleware
 
         # requests 请求参数
         self.url = url
@@ -277,10 +277,6 @@ class Request:
         """
         request_dict = {}
 
-        # 先取出 callback
-        if self.callback and not isinstance(self.callback, str):
-            request_dict['callback'] = self.callback.__name__
-
         # 提取其它参数
         for key, value in self.__dict__.items():
             # _打头的名字 和 无值的忽略
@@ -346,6 +342,10 @@ class Request:
         @param value:
         @return:
         """
+        # 判断 callback 保证不论怎么样都是字符串
+        if key == 'callback' and value and not isinstance(value, str):
+            value = value.__name__
+
         self.__dict__[key] = value
 
         if key in self.__class__.__REQUEST_ATTRS__:
